@@ -145,3 +145,27 @@ class OctaviaTest(base.TestCase):
             self.context,
             self.cluster
         )
+
+    @mock.patch("magnum.common.neutron.delete_floatingip")
+    @mock.patch('magnum.common.clients.OpenStackClients')
+    def test_delete_loadbalancers_already_deleted(self, mock_clients,
+                                                  mock_delete_fip):
+        mock_octavia_client = mock.MagicMock()
+        mock_octavia_client.load_balancer_list.return_value = {
+            "loadbalancers": []
+        }
+
+        mock_heat_client = mock.MagicMock()
+        mock_heat_client.resources.list.return_value = [
+            TestHeatLBResource(None)
+        ]
+
+        osc = mock.MagicMock()
+        mock_clients.return_value = osc
+        osc.octavia.return_value = mock_octavia_client
+        osc.heat.return_value = mock_heat_client
+
+        octavia.delete_loadbalancers(self.context, self.cluster)
+
+        self.assertFalse(mock_octavia_client.load_balancer_show.called)
+        self.assertFalse(mock_octavia_client.load_balancer_delete.called)
